Struct NoInitialCipherSuite
pub struct NoInitialCipherSuite { /* private fields */ }Available on crate feature
quic and (crate features rustls-aws-lc-rs or rustls-ring) only.Expand description
The initial cipher suite (AES-128-GCM-SHA256) is not available
When the cipher suite is supplied with_initial(), it must be
CipherSuite::TLS13_AES_128_GCM_SHA256. When the cipher suite is derived from a config’s
CryptoProvider, that provider must reference a cipher suite with the same ID.